@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1602';
+our $VERSION = '0.1603';
 
 use Math::Bezier;
 use MIDI::Simple;
@@ -221,13 +221,10 @@ sub metronome58 {
     my $bars = shift || $self->bars;
     for my $n (1 .. $bars) {
         $self->note($self->eighth, $self->closed_hh, $self->kick);
-        $self->note($self->sixteenth, $self->closed_hh);
-        $self->note($self->sixteenth, $self->kick);
+        $self->note($self->eighth, $self->closed_hh);
         $self->note($self->eighth, $self->closed_hh, $self->snare);
-        $self->note($self->sixteenth, $self->closed_hh);
-        $self->note($self->sixteenth, $self->snare);
-        $self->note($self->sixteenth, $self->closed_hh);
-        $self->note($self->sixteenth, $self->kick);
+        $self->note($self->eighth, $self->closed_hh);
+        $self->note($self->eighth, $self->closed_hh);
     }
 }
 
@@ -375,7 +372,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1602
+version 0.1603
 
 =head1 SYNOPSIS
 
@@ -402,7 +399,7 @@ version 0.1602
  $d->metronome44;  # 4/4 time for the number of bars
 
  $d->flam($d->quarter, $d->snare);
- $d->crescendo_roll([50, 127], $d->eighth, $d->thirtysecond);
+ $d->crescendo_roll([50, 127, 1], $d->eighth, $d->thirtysecond);
  $d->note($d->eighth, $d->crash1);
 
  # Alternate kick and snare
